/*
 * FileSystemSpec.java
 * Specification for the file system resource.
 *
 * Copyright (c) 2002, 2003 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Lesser 
 * General Public License.
 * 
 * See the file "license-lesser.terms" for information on 
 * usage and redistribution of this file.
 */

package edu.utah.janosvm.resources;

/**
 * Specification for the file system resource.  Basically, this lets you
 * "chroot()" a team.
 */
public final class FileSystemSpec
    extends ResourceSpec
    implements Cloneable
{
    /**
     * Constructor for the native part of the object.
     *
     * @param root The file system root.
     */
    private native void nativeConstructor(String root);

    /**
     * Finalizer for the native part of the object.
     */
    private native void nativeFinalizer();

    /**
     * Construct a FileSystemSpec with the given value.
     *
     * @param root The file system root directory or an empty string if the
     * team should not be able to access files.
     */
    public FileSystemSpec(String root)
    {
	if( root == null )
	{
	    throw new IllegalArgumentException("Null root directory.");
	}
	this.nativeConstructor(root);
    }

    /**
     * @return The root directory value.
     */
    public native String getRoot();

    protected void finalize()
    {
	this.nativeFinalizer();
    }

    public native Object clone();

    public boolean equals(Object obj)
    {
	boolean retval = false;

	if( obj instanceof FileSystemSpec )
	{
	    FileSystemSpec fss = (FileSystemSpec)obj;

	    if( fss.getRoot().equals(this.getRoot()) )
	    {
		retval = true;
	    }
	}
	return retval;
    }

    public String toString()
    {
	return "FileSystemSpec[root="
	    + this.getRoot()
	    + "]";
    }

    /**
     * @return A copy of this team's FileSystemSpec.
     */
    public static native FileSystemSpec current();

    /**
     * @return A FileSystemSpec with the default value.
     */
    public static FileSystemSpec defaultSpec()
    {
	return new FileSystemSpec("/");
    }
}
