/*
 * IOResource.java
 * Provides java level access to a team's IO resource.
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Lesser 
 * General Public License.
 * 
 * See the file "license-lesser.terms" for information on 
 * usage and redistribution of this file.
 */

package edu.utah.janosvm.resources;

/**
 * Provides java level access to the current team's IO resource.
 */
public final class IOResource
{
    static {
	System.loadLibrary("kaffejanosvm");
    }
    
    /*
     * XXX The ACCOUNT_* values match internal ones, make sure to update either
     * side if there is a change.
     */

    /**
     * The interprocess communication account.
     */
    public static final int ACCOUNT_IPC = 0;
    
    /**
     * The disk account.
     */
    public static final int ACCOUNT_DISK = 1;
    
    /**
     * The network account.
     */
    public static final int ACCOUNT_NETWORK = 2;
    
    /**
     * The network packet account.
     */
    public static final int ACCOUNT_NETWORK_PACKET = 3;
    
    /**
     * @param is The new IOSpec for this team.
     */
    public static native void change(int account, IOSpec is)
	throws ResourceSpecException;
    
    /**
     * @param account The IO account type.
     * @return The number of bytes/packets read by this team in the given
     * account.
     */
    public static native long getIn(int account);

    /**
     * @param account The IO account type.
     * @return The number of bytes/packets generated by this team in the given
     * account.
     */
    public static native long getOut(int account);

    /**
     * Its a static only class.
     */
    private IOResource()
    {
    }
}
