/*
 * DeadTeamException.java
 * Exception thrown when a visit cannot be done because one of the teams
 * involved is dead.
 *
 * Copyright (c) 2000, 2001 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Lesser 
 * General Public License.
 * 
 * See the file "license-lesser.terms" for information on 
 * usage and redistribution of this file.
 */

package edu.utah.janosvm.sys;

/**
 * Exception thrown when a {@linkplain Team#switchTo visit} or {@linkplain
 * Team#pushReservation reservation} cannot be secured because one of
 * the teams involved is dead.  
 *
 * <p>While a <code>DeadTeamException</code> usually implies that the other team is
 * dead, it can mean that the current team is dead.  Normally, if the
 * current team is dead, the reservation won't even return, but if
 * there are nested visits preventing termination of the current team,
 * then this exception will be thrown because the current team died.
 * The current thread will die when the visit is complete.
 *
 * <p>There is currently no way to distinguish the current team's
 * death from the other team's death.
 *
 * <p>See {@link TeamReservation} for more details on visits and the
 * special handling of code running during a visit.
 *
 * @see Exportable#switchToOwner
 * @see Exportable#pushOwnerReservation
 * @see PortAuthority#importObject
 * @see TeamHandle#importObject
 * @see Team#create
 * @see TeamHandle#pushReservation
 * @see TeamHandle#switchTo
 * @author Tim Stack, <a href="mailto:janos-discuss@flux.cs.utah.edu">Utah Janos Team</a>
 */
public class DeadTeamException
    extends Exception
{
    public DeadTeamException()
    {
	super();
    }

    public DeadTeamException(String s)
    {
	super(s);
    }
}
